"""
To flash the msp430 board, the following program can be used:

http://www.ti.com/tool/msp430-flasher

"""

from .arch import Msp430Arch

__all__ = ["Msp430Arch"]
